<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name>AppMain</name>
    <message>
        <location filename="../src/common/vlcplayer.cpp" line="87"/>
        <source>Voice Notes</source>
        <translation>Nota Suara</translation>
    </message>
</context>
<context>
    <name>DefaultName</name>
    <message>
        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
        <source>Notebook</source>
        <translation>Buku nota</translation>
    </message>
    <message>
        <location filename="../src/importolddata/olddbvisistors.cpp" line="139"/>
        <source>Voice</source>
        <translation>Suara</translation>
    </message>
    <message>
        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
</context>
<context>
    <name>FolderListView</name>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="517"/>
        <source>Rename</source>
        <translation type="unfinished">Nama Semula</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="526"/>
        <source>Delete</source>
        <translation type="unfinished">Padam</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
        <source>New Note</source>
        <translation>Nota Baru</translation>
    </message>
</context>
<context>
    <name>InitialInterface</name>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
        <source>After creating a new notepad, you can start recording voice and text</source>
        <translation>Selepas mencipta buku catatan baru, anda boleh mula merekod suara dan teks</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Cipta Buku Nota</translation>
    </message>
</context>
<context>
    <name>ItemListView</name>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source>move </source>
        <translation>gerakkan </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
        <source> notes to :</source>
        <translation> nota ke :</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
        <source> note to :</source>
        <translation> nota ke :</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
        <source>Save As</source>
        <translation>Simpan Sebagai</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
        <source>No search results</source>
        <translation type="unfinished">Tiada keputusan gelintar</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Unpin</source>
        <translation>Buka Pemecah</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
        <source>Sticky on Top</source>
        <translation type="unfinished">Lekat paling Atas</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
        <source>Sticky Notes</source>
        <translation type="unfinished">Nota Lekat</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
        <source>Create Notebook</source>
        <translation type="unfinished">Cipta Buku Nota</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
        <source>Search</source>
        <translation type="unfinished">Gelintar</translation>
    </message>
</context>
<context>
    <name>MoveDialog</name>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
        <source>Move Note</source>
        <translation>Gerakkan Nota</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
        <source>Cancel</source>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>MultipleChoices</name>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
        <source>%1 note selected</source>
        <translation>%1 nota dipilih</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
        <source>Move</source>
        <translation type="unfinished">Alih</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
        <source>Save Note</source>
        <translation>Simpan Nota</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
        <source>Save Voice</source>
        <translation>Simpan Suara</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
        <source>Delete</source>
        <translation type="unfinished">Padam</translation>
    </message>
</context>
<context>
    <name>NoteDetailContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="69"/>
        <source>Save as MP3</source>
        <translation>Simpan Sebagai MP3</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="70"/>
        <source>Voice to Text</source>
        <translation>Suara ke Teks</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="71"/>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="72"/>
        <source>Select all</source>
        <translation>Pilih Semua</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="73"/>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="74"/>
        <source>Cut</source>
        <translation>Potong</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="75"/>
        <source>Paste</source>
        <translation>Tampal</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="78"/>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="84"/>
        <source>Save as</source>
        <translation>Simpan sebagai</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="93"/>
        <source>Text to Speech</source>
        <translation>Teks ke Suara</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="94"/>
        <source>Stop reading</source>
        <translation>Berhenti membaca</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="95"/>
        <source>Speech to Text</source>
        <translation>Suara ke Teks</translation>
    </message>
</context>
<context>
    <name>NotebookContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="47"/>
        <source>Rename</source>
        <translation>Nama Semula</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="48"/>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="49"/>
        <source>New note</source>
        <translation type="unfinished">Nota baharu</translation>
    </message>
</context>
<context>
    <name>NotesContextMenu</name>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="63"/>
        <source>Save as HTML</source>
        <translation>Simpan sebagai HTML</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="64"/>
        <source>Save as TXT</source>
        <translation>Simpan sebagai TXT</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="57"/>
        <source>Save note</source>
        <translation>Simpan nota</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="52"/>
        <source>Rename</source>
        <translation>Nama Semula</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="54"/>
        <source>Move</source>
        <translation>Alih</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="55"/>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="58"/>
        <source>Save voice recording</source>
        <translation>Simpan rakaman suara</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="60"/>
        <source>New note</source>
        <translation>Nota baharu</translation>
    </message>
    <message>
        <location filename="../src/common/actionmanager.cpp" line="53"/>
        <source>Sticky on Top</source>
        <translation>Lekat paling Atas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
        <source>Please install 'UOS AI' from the App Store before using</source>
        <translation>Sila pasang 'UOS AI' daripada Perniagaan Aplikasi sebelum menggunakan</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
        <source>No audio input device detected. Please check and try again</source>
        <translation>Tiada peranti input audio yang dideteksi. Sila semak dan cuba semula</translation>
    </message>
    <message>
        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
        <source>No audio output device detected. Please check and try again</source>
        <translation>Tiada peranti output audio yang dideteksi. Sila semak dan cuba semula</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="99"/>
        <source>deepin-voice-note</source>
        <translation>deepin-voice-note</translation>
    </message>
</context>
<context>
    <name>Setting</name>
    <message>
        <location filename="../src/common/setting.cpp" line="24"/>
        <source>Basic</source>
        <translation>Asas</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="25"/>
        <source>Audio Source</source>
        <translation>Sumber Audio</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="26"/>
        <source>Internal</source>
        <translation>Dalaman</translation>
    </message>
    <message>
        <location filename="../src/common/setting.cpp" line="27"/>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="27"/>
        <source>Basic</source>
        <translation type="unfinished">Asas</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="32"/>
        <source>Audio Source</source>
        <translation type="unfinished">Sumber Audio</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="59"/>
        <source>Internal</source>
        <translation type="unfinished">Dalaman</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/SettingDialog.qml" line="68"/>
        <source>Microphone</source>
        <translation type="unfinished">Mikrofon</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
        <source>New notebook</source>
        <translation>Buku catatan baru</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
        <source>Rename notebook</source>
        <translation>Ubah nama buku catatan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
        <source>Delete notebook</source>
        <translation>Padam buku catatan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
        <source>New note</source>
        <translation type="unfinished">Nota baharu</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
        <source>Rename note</source>
        <translation>Ubah nama nota</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
        <source>Delete note</source>
        <translation>Padam nota</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
        <source>Play/Pause</source>
        <translation>Tonton/Menghentikan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
        <source>Record voice</source>
        <translation>Rekod suara</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
        <source>Save note</source>
        <translation type="unfinished">Simpan nota</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
        <source>Save recordings</source>
        <translation>Simpan rekod</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
        <source>Select all</source>
        <translation>Pilih semua</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
        <source>Copy</source>
        <translation type="unfinished">Salin</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
        <source>Cut</source>
        <translation type="unfinished">Potong</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
        <source>Paste</source>
        <translation type="unfinished">Tampal</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
        <source>Undo</source>
        <translation>Batalkan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
        <source>Redo</source>
        <translation>Ulangkan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
        <source>Delete</source>
        <translation type="unfinished">Padam</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
        <source>Display shortcuts</source>
        <translation>Tunjukkan kekunci</translation>
    </message>
</context>
<context>
    <name>ShortcutsGroups</name>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
        <source>Notebooks</source>
        <translation>Buku catatan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
        <source>Notes</source>
        <translation>Catatan</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
        <source>Edit</source>
        <translation>Sunting</translation>
    </message>
    <message>
        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
        <source>Settings</source>
        <translation type="unfinished">Tetapan</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="16"/>
        <source>Settings</source>
        <translation type="unfinished">Tetapan</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
        <source>Privacy Policy</source>
        <translation>Dasar Privasi</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
        <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
        <translation>Catatan Suara adalah alat catatan ringan untuk membuat catatan teks dan rekaman suara.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
        <source>Voice Note</source>
        <translation>Catatan Suara</translation>
    </message>
</context>
<context>
    <name>UpgradeView</name>
    <message>
        <location filename="../src/importolddata/upgradeview.cpp" line="35"/>
        <source>Importing notes from the old version, please wait...</source>
        <translation>Mengimport nota dari versi lama, tunggu sebentar...</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="46"/>
        <source>1 min ago</source>
        <translation>1 min yang lalu</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="48"/>
        <source>%1 mins ago</source>
        <translation>%1 min yang lalu</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="56"/>
        <source>Yesterday</source>
        <translation>Semalam</translation>
    </message>
    <message>
        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
        <source>2 mins ago</source>
        <translation>2 minit lepas</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialog</name>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
        <source>Are you sure you want to delete this notebook?
All notes in it will be deleted</source>
        <translation>Adakah anda pasti ingin memadamkan buku catatan ini?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Anda pasti mahu menghentikan rakaman semasa?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Tidak dapat menukar format nota suara ini, kerana nota melebihi 20 minit tidak disokong buat masa ini.</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">Menukar format satu nota suara sekarang. Anda mahu hentikannya?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Volum input rendah boleh mengakibatkan rakaman menjadi bermasalah. Anda mahu teruskan?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">Rakaman terklip dan teks yang ditukarkan tidak akan ditampal. Anda pasti mahu teruskan?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Anda pasti mahu memadam nota ini?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Anda pasti mahu memadam %1 nota terpilih?</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation type="unfinished">Sahkan</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
        <source>Save failed</source>
        <translation type="unfinished">Gagal disimpan</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">Anda tiada keizinan untuk menyimpan fail di sini</translation>
    </message>
    <message>
        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">Nota suara telah dipadamkan</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogHandler</name>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
        <source>Are you sure you want to delete this notebook?</source>
        <translation>Semua catatan dalamnya akan dipadamkan</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
        <source>Do you want to stop the current recording?</source>
        <translation type="unfinished">Anda pasti mahu menghentikan rakaman semasa?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="103"/>
        <source>Are you sure you want to delete the selected %1 notes?</source>
        <translation type="unfinished">Anda pasti mahu memadam %1 nota terpilih?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="107"/>
        <source>Are you sure you want to delete this note?</source>
        <translation type="unfinished">Anda pasti mahu memadam nota ini?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="110"/>
        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
        <translation type="unfinished">Tidak dapat menukar format nota suara ini, kerana nota melebihi 20 minit tidak disokong buat masa ini.</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="114"/>
        <source>Converting a voice note now. Do you want to stop it?</source>
        <translation type="unfinished">Menukar format satu nota suara sekarang. Anda mahu hentikannya?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="116"/>
        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
        <translation type="unfinished">Volum input rendah boleh mengakibatkan rakaman menjadi bermasalah. Anda mahu teruskan?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="119"/>
        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
        <translation type="unfinished">Rakaman terklip dan teks yang ditukarkan tidak akan ditampal. Anda pasti mahu teruskan?</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="123"/>
        <source>Save failed</source>
        <translation type="unfinished">Gagal disimpan</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="125"/>
        <source>You do not have permission to save files there</source>
        <translation type="unfinished">Anda tiada keizinan untuk menyimpan fail di sini</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="127"/>
        <source>The voice note has been deleted</source>
        <translation type="unfinished">Nota suara telah dipadamkan</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
        <source>The voice conversion failed due to the poor network connection, please have a check</source>
        <translation>Pemformatan suara gagal disebabkan oleh keadaan sambungan rambat yang buruk, sila semak</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
        <source>All notes in it will be deleted</source>
        <translation>simpan sebagai MP3</translation>
    </message>
    <message>
        <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
        <source>Delete</source>
        <translation type="unfinished">Padam</translation>
    </message>
</context>
<context>
    <name>VNoteMessageDialogLoader</name>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="150"/>
        <source>Cancel</source>
        <translation type="unfinished">Batal</translation>
    </message>
    <message>
        <location filename="../src/gui/dialog/VNoteMessageDialogLoader.qml" line="183"/>
        <source>Confirm</source>
        <translation type="unfinished">Sahkan</translation>
    </message>
</context>
<context>
    <name>WebEngineHandler</name>
    <message>
        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
        <source>save as MP3</source>
        <translation>Cipta Catatan</translation>
    </message>
</context>
<context>
    <name>WindowTitleBar</name>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
        <source>Create Note</source>
        <translation>Mula Rekod</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>Start recording</source>
        <translation>Tiada peranti rekod terdeteksi</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
        <source>No recording device detected</source>
        <translation>Sisipkan gambar</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
        <source>Insert picture</source>
        <translation>Suara Ke Teks</translation>
    </message>
</context>
<context>
    <name>web</name>
    <message>
        <location filename="../src/common/jscontent.cpp" line="146"/>
        <source>Font</source>
        <translation>Fon</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="147"/>
        <source>Font size</source>
        <translation>Saiz fon</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="148"/>
        <source>Font color</source>
        <translation>Warna fon</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="149"/>
        <source>Text highlight color</source>
        <translation>Warna sorot teks</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="150"/>
        <source>Bold</source>
        <translation>Tebal</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="151"/>
        <source>Italic</source>
        <translation>Condong</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="152"/>
        <source>Underline</source>
        <translation>Garis Bawah</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="153"/>
        <source>Strikethrough</source>
        <translation>Coret Tembus</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="154"/>
        <source>Bullets</source>
        <translation>Bullet</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="155"/>
        <source>Numbering</source>
        <translation>Pernomboran</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="156"/>
        <source>More colors</source>
        <translation>Lagi banyak warna</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="157"/>
        <source>Recent</source>
        <translation>Baru-baru Ini</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="173"/>
        <source>Voice To Text</source>
        <translation>Mengubah suara ke teks</translation>
    </message>
    <message>
        <location filename="../src/common/jscontent.cpp" line="174"/>
        <source>Converting voice to text</source>
        <translation>Mengubah suara kepada teks</translation>
    </message>
</context>
</TS>
